const char * _session_dbus = 
"<!DOCTYPE node PUBLIC \"-//freedesktop//DTD D-BUS Object Introspection 1.0//EN\" \"http://www.freedesktop.org/standards/dbus/1.0/introspect.dtd\">\n"
"<node name=\"/com/canonical/indicator/session/service\">\n"
"  <interface name=\"com.canonical.indicator.session.service\">\n"
"\n"
"    <method name=\"GetUserRealName\">\n"
"      <arg name=\"name\" direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"GetUserMenuVisibility\">\n"
"      <arg name=\"update\" direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <signal name=\"UserRealNameUpdated\">\n"
"      <arg name=\"name\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"UserMenuIsVisible\">\n"
"      <arg name=\"update\" type=\"b\"/>\n"
"    </signal>\n"
"    <signal name=\"RestartRequired\">\n"
"    </signal>\n"
"  </interface>\n"
"</node>\n"
;
